// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
funcprot(0);
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// Get body position from 'cent' in EOD
// cjd: TREF time scale

function [pos_ECI]=getBodyPos(name,cjd)
  cent="Earth";
  pos_ICRS=CL_eph_de405(name,cjd,cent);

  pos_ECI=CL_fr_convert("ICRS","ECI",cjd,pos_ICRS);
endfunction

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

function [azim,elev]=sphPos(t,loc,cbody)
  pos_ECI=[];

  pos_ECI=getBodyPos(cbody,t);

  // Transform position of celestial body in ECF frame
  // (Earth Centered Fixed Frame)

  pos_ECF=CL_fr_convert("ECI","ECF",t,pos_ECI);

  // Transform elliptical coordinates of the position of celestial body
  // to cartesian coordinates

  loc_car=CL_co_ell2car(loc);

  // Get the transformation matrix to the local Topocentric North frame
  // The "topocentric North" local frame is defined as follows:
  // X: unit vector in the horizontal plane and towards norh
  // Y: unit vector in the horizontal plane and towards west
  // Z: unit vector in direction of the local vertical

  M_topoN=CL_fr_topoNMat(loc);

  // Transform position of celestial body to the local Topocentric North
  // frame in cartesian coordinates

  pos_topoN=M_topoN*(pos_ECF-loc_car);

  // Transform cartesian coordinates to spherical coordinates

  pos_topoN_sph=CL_co_car2sph(pos_topoN);

  // Get azimuth and elevation of celestial body

  azim=pos_topoN_sph(1);
  elev=pos_topoN_sph(2);

endfunction

// #####################################################################
// Main

r2d=(180/%pi);

// longitude/latitude/altitude of location

lon=11.42*%CL_deg2rad;
lat=48.15*%CL_deg2rad;
alt=531;

// scal=reference date (string, calendar)
scal=[];

scal="2014/04/01 12:00:00.000";

loc=[lon;lat;alt];

t0=CL_dat_cal2cjd(CL_dat_str2cal(scal));

dur = [60,60]; // days before/after

tsteps = 1; // steps (trajectory) - days
//           ^^ Not used

cjd_ref = t0;
cjd_start = cjd_ref - dur(1);
cjd_end = cjd_ref + dur(2);

traj_step = tsteps;

// dates for trajectory
cjd_traj = cjd_ref;
if (traj_step > 0)
  cjd_traj = cjd_start : traj_step : cjd_end;
end

nbTimes=size(cjd_traj,"c");

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

azimv=[];
elevv=[];

cbody="Mars";

for Ix=1:nbTimes
    [azimv(Ix),elevv(Ix)]=sphPos(cjd_traj(Ix),loc,cbody)
end

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

xv=cos(azimv) .* cos(elevv);
yv=sin(azimv) .* cos(elevv);
zv=sin(elevv);

azimvd=azimv*r2d;
elevvd=elevv*r2d;

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle50=scf(50);
clf(my_handle50,"reset");
a=gca();
a.isoview='off';

nbazims=size(azimv,"r");

wdata=linspace(1,nbazims,nbazims);

subplot(211)
plot2d(wdata,azimvd,color("steelblue3"));
subplot(212)
plot2d(wdata,elevvd,color("steelblue3"));

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle52=scf(52);
clf(my_handle52,"reset");
a=gca();

subplot(2,1,1);
param3d(xv,yv,zv);
subplot(2,1,2);
param3d(xv,yv,zv,flag=[5,4],ebox=[-1,1,-1,1,-1,1]);




